# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.21.0-rc1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from py_gitea_opensuse_org.models.change_files_options import ChangeFilesOptions


class TestChangeFilesOptions(unittest.TestCase):
    """ChangeFilesOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChangeFilesOptions:
        """Test ChangeFilesOptions
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ChangeFilesOptions`
        """
        model = ChangeFilesOptions()
        if include_optional:
            return ChangeFilesOptions(
                author = py_gitea_opensuse_org.models.identity.Identity(
                    email = '', 
                    name = '', ),
                branch = '',
                committer = py_gitea_opensuse_org.models.identity.Identity(
                    email = '', 
                    name = '', ),
                dates = py_gitea_opensuse_org.models.commit_date_options.CommitDateOptions(
                    author = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    committer = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                files = [
                    py_gitea_opensuse_org.models.change_file_operation.ChangeFileOperation(
                        content = '', 
                        from_path = '', 
                        operation = 'create', 
                        path = '', 
                        sha = '', )
                    ],
                message = '',
                new_branch = '',
                signoff = True
            )
        else:
            return ChangeFilesOptions(
                files = [
                    py_gitea_opensuse_org.models.change_file_operation.ChangeFileOperation(
                        content = '', 
                        from_path = '', 
                        operation = 'create', 
                        path = '', 
                        sha = '', )
                    ],
        )
        """

    def testChangeFilesOptions(self):
        """Test ChangeFilesOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.edit_user_option import EditUserOption  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestEditUserOption(unittest.TestCase):
    """EditUserOption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EditUserOption
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `EditUserOption`
        """
        model = py_gitea_opensuse_org.models.edit_user_option.EditUserOption()  # noqa: E501
        if include_optional :
            return EditUserOption(
                active = True, 
                admin = True, 
                allow_create_organization = True, 
                allow_git_hook = True, 
                allow_import_local = True, 
                description = '', 
                email = '', 
                full_name = '', 
                location = '', 
                login_name = '', 
                max_repo_creation = 56, 
                must_change_password = True, 
                password = '', 
                prohibit_login = True, 
                restricted = True, 
                source_id = 56, 
                visibility = '', 
                website = ''
            )
        else :
            return EditUserOption(
                login_name = '',
                source_id = 56,
        )
        """

    def testEditUserOption(self):
        """Test EditUserOption"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.pull_request import PullRequest  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestPullRequest(unittest.TestCase):
    """PullRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PullRequest
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PullRequest`
        """
        model = py_gitea_opensuse_org.models.pull_request.PullRequest()  # noqa: E501
        if include_optional :
            return PullRequest(
                allow_maintainer_edit = True, 
                assignee = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', ), 
                assignees = [
                    py_gitea_opensuse_org.models.user.User(
                        active = True, 
                        avatar_url = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        email = '', 
                        followers_count = 56, 
                        following_count = 56, 
                        full_name = '', 
                        id = 56, 
                        is_admin = True, 
                        language = '', 
                        last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        location = '', 
                        login = '', 
                        login_name = 'empty', 
                        prohibit_login = True, 
                        restricted = True, 
                        starred_repos_count = 56, 
                        visibility = '', 
                        website = '', )
                    ], 
                base = py_gitea_opensuse_org.models.pr_branch_info.PRBranchInfo(
                    label = '', 
                    ref = '', 
                    repo = py_gitea_opensuse_org.models.repository.Repository(
                        allow_merge_commits = True, 
                        allow_rebase = True, 
                        allow_rebase_explicit = True, 
                        allow_rebase_update = True, 
                        allow_squash_merge = True, 
                        archived = True, 
                        avatar_url = '', 
                        clone_url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        default_allow_maintainer_edit = True, 
                        default_branch = '', 
                        default_delete_branch_after_merge = True, 
                        default_merge_style = '', 
                        description = '', 
                        empty = True, 
                        external_tracker = py_gitea_opensuse_org.models.external_tracker.ExternalTracker(
                            external_tracker_format = '', 
                            external_tracker_regexp_pattern = '', 
                            external_tracker_style = '', 
                            external_tracker_url = '', ), 
                        external_wiki = py_gitea_opensuse_org.models.external_wiki.ExternalWiki(
                            external_wiki_url = '', ), 
                        fork = True, 
                        forks_count = 56, 
                        full_name = '', 
                        has_issues = True, 
                        has_projects = True, 
                        has_pull_requests = True, 
                        has_wiki = True, 
                        hash_type = '', 
                        html_url = '', 
                        id = 56, 
                        ignore_whitespace_conflicts = True, 
                        internal = True, 
                        internal_tracker = py_gitea_opensuse_org.models.internal_tracker.InternalTracker(
                            allow_only_contributors_to_track_time = True, 
                            enable_issue_dependencies = True, 
                            enable_time_tracker = True, ), 
                        language = '', 
                        languages_url = '', 
                        link = '', 
                        mirror = True, 
                        mirror_interval = '', 
                        mirror_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        open_issues_count = 56, 
                        open_pr_counter = 56, 
                        original_url = '', 
                        owner = py_gitea_opensuse_org.models.user.User(
                            active = True, 
                            avatar_url = '', 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            email = '', 
                            followers_count = 56, 
                            following_count = 56, 
                            full_name = '', 
                            id = 56, 
                            is_admin = True, 
                            language = '', 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            location = '', 
                            login = '', 
                            login_name = 'empty', 
                            prohibit_login = True, 
                            restricted = True, 
                            starred_repos_count = 56, 
                            visibility = '', 
                            website = '', ), 
                        parent = py_gitea_opensuse_org.models.repository.Repository(
                            allow_merge_commits = True, 
                            allow_rebase = True, 
                            allow_rebase_explicit = True, 
                            allow_rebase_update = True, 
                            allow_squash_merge = True, 
                            archived = True, 
                            avatar_url = '', 
                            clone_url = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            default_allow_maintainer_edit = True, 
                            default_branch = '', 
                            default_delete_branch_after_merge = True, 
                            default_merge_style = '', 
                            description = '', 
                            empty = True, 
                            fork = True, 
                            forks_count = 56, 
                            full_name = '', 
                            has_issues = True, 
                            has_projects = True, 
                            has_pull_requests = True, 
                            has_wiki = True, 
                            hash_type = '', 
                            html_url = '', 
                            id = 56, 
                            ignore_whitespace_conflicts = True, 
                            internal = True, 
                            language = '', 
                            languages_url = '', 
                            link = '', 
                            mirror = True, 
                            mirror_interval = '', 
                            mirror_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            open_issues_count = 56, 
                            open_pr_counter = 56, 
                            original_url = '', 
                            permissions = py_gitea_opensuse_org.models.permission.Permission(
                                admin = True, 
                                pull = True, 
                                push = True, ), 
                            private = True, 
                            release_counter = 56, 
                            repo_transfer = py_gitea_opensuse_org.models.repo_transfer.RepoTransfer(
                                doer = py_gitea_opensuse_org.models.user.User(
                                    active = True, 
                                    avatar_url = '', 
                                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    description = '', 
                                    email = '', 
                                    followers_count = 56, 
                                    following_count = 56, 
                                    full_name = '', 
                                    id = 56, 
                                    is_admin = True, 
                                    language = '', 
                                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    location = '', 
                                    login = '', 
                                    login_name = 'empty', 
                                    prohibit_login = True, 
                                    restricted = True, 
                                    starred_repos_count = 56, 
                                    visibility = '', 
                                    website = '', ), 
                                recipient = , 
                                teams = [
                                    py_gitea_opensuse_org.models.team.Team(
                                        can_create_org_repo = True, 
                                        description = '', 
                                        id = 56, 
                                        includes_all_repositories = True, 
                                        name = '', 
                                        organization = py_gitea_opensuse_org.models.organization.Organization(
                                            avatar_url = '', 
                                            description = '', 
                                            full_name = '', 
                                            id = 56, 
                                            location = '', 
                                            name = '', 
                                            repo_admin_change_team_access = True, 
                                            username = '', 
                                            visibility = '', 
                                            website = '', ), 
                                        permission = 'none', 
                                        units = [repo.code, repo.issues, repo.ext_issues, repo.wiki, repo.pulls, repo.releases, repo.projects, repo.ext_wiki], 
                                        units_map = {"repo.code":"read","repo.ext_issues":"none","repo.ext_wiki":"none","repo.issues":"write","repo.projects":"none","repo.pulls":"owner","repo.releases":"none","repo.wiki":"admin"}, )
                                    ], ), 
                            size = 56, 
                            ssh_url = '', 
                            stars_count = 56, 
                            template = True, 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            watchers_count = 56, 
                            website = '', ), 
                        permissions = py_gitea_opensuse_org.models.permission.Permission(
                            admin = True, 
                            pull = True, 
                            push = True, ), 
                        private = True, 
                        release_counter = 56, 
                        repo_transfer = py_gitea_opensuse_org.models.repo_transfer.RepoTransfer(), 
                        size = 56, 
                        ssh_url = '', 
                        stars_count = 56, 
                        template = True, 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        watchers_count = 56, 
                        website = '', ), 
                    repo_id = 56, 
                    sha = '', ), 
                body = '', 
                closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                comments = 56, 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                diff_url = '', 
                due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                head = py_gitea_opensuse_org.models.pr_branch_info.PRBranchInfo(
                    label = '', 
                    ref = '', 
                    repo = py_gitea_opensuse_org.models.repository.Repository(
                        allow_merge_commits = True, 
                        allow_rebase = True, 
                        allow_rebase_explicit = True, 
                        allow_rebase_update = True, 
                        allow_squash_merge = True, 
                        archived = True, 
                        avatar_url = '', 
                        clone_url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        default_allow_maintainer_edit = True, 
                        default_branch = '', 
                        default_delete_branch_after_merge = True, 
                        default_merge_style = '', 
                        description = '', 
                        empty = True, 
                        external_tracker = py_gitea_opensuse_org.models.external_tracker.ExternalTracker(
                            external_tracker_format = '', 
                            external_tracker_regexp_pattern = '', 
                            external_tracker_style = '', 
                            external_tracker_url = '', ), 
                        external_wiki = py_gitea_opensuse_org.models.external_wiki.ExternalWiki(
                            external_wiki_url = '', ), 
                        fork = True, 
                        forks_count = 56, 
                        full_name = '', 
                        has_issues = True, 
                        has_projects = True, 
                        has_pull_requests = True, 
                        has_wiki = True, 
                        hash_type = '', 
                        html_url = '', 
                        id = 56, 
                        ignore_whitespace_conflicts = True, 
                        internal = True, 
                        internal_tracker = py_gitea_opensuse_org.models.internal_tracker.InternalTracker(
                            allow_only_contributors_to_track_time = True, 
                            enable_issue_dependencies = True, 
                            enable_time_tracker = True, ), 
                        language = '', 
                        languages_url = '', 
                        link = '', 
                        mirror = True, 
                        mirror_interval = '', 
                        mirror_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        open_issues_count = 56, 
                        open_pr_counter = 56, 
                        original_url = '', 
                        owner = py_gitea_opensuse_org.models.user.User(
                            active = True, 
                            avatar_url = '', 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            email = '', 
                            followers_count = 56, 
                            following_count = 56, 
                            full_name = '', 
                            id = 56, 
                            is_admin = True, 
                            language = '', 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            location = '', 
                            login = '', 
                            login_name = 'empty', 
                            prohibit_login = True, 
                            restricted = True, 
                            starred_repos_count = 56, 
                            visibility = '', 
                            website = '', ), 
                        parent = py_gitea_opensuse_org.models.repository.Repository(
                            allow_merge_commits = True, 
                            allow_rebase = True, 
                            allow_rebase_explicit = True, 
                            allow_rebase_update = True, 
                            allow_squash_merge = True, 
                            archived = True, 
                            avatar_url = '', 
                            clone_url = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            default_allow_maintainer_edit = True, 
                            default_branch = '', 
                            default_delete_branch_after_merge = True, 
                            default_merge_style = '', 
                            description = '', 
                            empty = True, 
                            fork = True, 
                            forks_count = 56, 
                            full_name = '', 
                            has_issues = True, 
                            has_projects = True, 
                            has_pull_requests = True, 
                            has_wiki = True, 
                            hash_type = '', 
                            html_url = '', 
                            id = 56, 
                            ignore_whitespace_conflicts = True, 
                            internal = True, 
                            language = '', 
                            languages_url = '', 
                            link = '', 
                            mirror = True, 
                            mirror_interval = '', 
                            mirror_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            open_issues_count = 56, 
                            open_pr_counter = 56, 
                            original_url = '', 
                            permissions = py_gitea_opensuse_org.models.permission.Permission(
                                admin = True, 
                                pull = True, 
                                push = True, ), 
                            private = True, 
                            release_counter = 56, 
                            repo_transfer = py_gitea_opensuse_org.models.repo_transfer.RepoTransfer(
                                doer = py_gitea_opensuse_org.models.user.User(
                                    active = True, 
                                    avatar_url = '', 
                                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    description = '', 
                                    email = '', 
                                    followers_count = 56, 
                                    following_count = 56, 
                                    full_name = '', 
                                    id = 56, 
                                    is_admin = True, 
                                    language = '', 
                                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    location = '', 
                                    login = '', 
                                    login_name = 'empty', 
                                    prohibit_login = True, 
                                    restricted = True, 
                                    starred_repos_count = 56, 
                                    visibility = '', 
                                    website = '', ), 
                                recipient = , 
                                teams = [
                                    py_gitea_opensuse_org.models.team.Team(
                                        can_create_org_repo = True, 
                                        description = '', 
                                        id = 56, 
                                        includes_all_repositories = True, 
                                        name = '', 
                                        organization = py_gitea_opensuse_org.models.organization.Organization(
                                            avatar_url = '', 
                                            description = '', 
                                            full_name = '', 
                                            id = 56, 
                                            location = '', 
                                            name = '', 
                                            repo_admin_change_team_access = True, 
                                            username = '', 
                                            visibility = '', 
                                            website = '', ), 
                                        permission = 'none', 
                                        units = [repo.code, repo.issues, repo.ext_issues, repo.wiki, repo.pulls, repo.releases, repo.projects, repo.ext_wiki], 
                                        units_map = {"repo.code":"read","repo.ext_issues":"none","repo.ext_wiki":"none","repo.issues":"write","repo.projects":"none","repo.pulls":"owner","repo.releases":"none","repo.wiki":"admin"}, )
                                    ], ), 
                            size = 56, 
                            ssh_url = '', 
                            stars_count = 56, 
                            template = True, 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            watchers_count = 56, 
                            website = '', ), 
                        permissions = py_gitea_opensuse_org.models.permission.Permission(
                            admin = True, 
                            pull = True, 
                            push = True, ), 
                        private = True, 
                        release_counter = 56, 
                        repo_transfer = py_gitea_opensuse_org.models.repo_transfer.RepoTransfer(), 
                        size = 56, 
                        ssh_url = '', 
                        stars_count = 56, 
                        template = True, 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        watchers_count = 56, 
                        website = '', ), 
                    repo_id = 56, 
                    sha = '', ), 
                html_url = '', 
                id = 56, 
                is_locked = True, 
                labels = [
                    py_gitea_opensuse_org.models.label.Label(
                        color = '00aabb', 
                        description = '', 
                        exclusive = False, 
                        id = 56, 
                        name = '', 
                        url = '', )
                    ], 
                merge_base = '', 
                merge_commit_sha = '', 
                mergeable = True, 
                merged = True, 
                merged_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                merged_by = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', ), 
                milestone = py_gitea_opensuse_org.models.milestone.Milestone(
                    closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    closed_issues = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    due_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = 56, 
                    open_issues = 56, 
                    state = '', 
                    title = '', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                number = 56, 
                patch_url = '', 
                state = '', 
                title = '', 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                url = '', 
                user = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', )
            )
        else :
            return PullRequest(
        )
        """

    def testPullRequest(self):
        """Test PullRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.repository_api import RepositoryApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestRepositoryApi(unittest.TestCase):
    """RepositoryApi unit test stubs"""

    def setUp(self):
        self.api = (
            py_gitea_opensuse_org.api.repository_api.RepositoryApi()
        )  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_repo_transfer(self):
        """Test case for accept_repo_transfer

        Accept a repo transfer  # noqa: E501
        """
        pass

    def test_create_current_user_repo(self):
        """Test case for create_current_user_repo

        Create a repository  # noqa: E501
        """
        pass

    def test_create_fork(self):
        """Test case for create_fork

        Fork a repository  # noqa: E501
        """
        pass

    def test_generate_repo(self):
        """Test case for generate_repo

        Create a repository using a template  # noqa: E501
        """
        pass

    def test_get_annotated_tag(self):
        """Test case for get_annotated_tag

        Gets the tag object of an annotated tag (not lightweight tags)  # noqa: E501
        """
        pass

    def test_get_blob(self):
        """Test case for get_blob

        Gets the blob of a repository.  # noqa: E501
        """
        pass

    def test_get_tree(self):
        """Test case for get_tree

        Gets the tree of a repository.  # noqa: E501
        """
        pass

    def test_list_forks(self):
        """Test case for list_forks

        List a repository's forks  # noqa: E501
        """
        pass

    def test_reject_repo_transfer(self):
        """Test case for reject_repo_transfer

        Reject a repo transfer  # noqa: E501
        """
        pass

    def test_repo_add_collaborator(self):
        """Test case for repo_add_collaborator

        Add a collaborator to a repository  # noqa: E501
        """
        pass

    def test_repo_add_push_mirror(self):
        """Test case for repo_add_push_mirror

        add a push mirror to the repository  # noqa: E501
        """
        pass

    def test_repo_add_team(self):
        """Test case for repo_add_team

        Add a team to a repository  # noqa: E501
        """
        pass

    def test_repo_add_topic(self):
        """Test case for repo_add_topic

        Add a topic to a repository  # noqa: E501
        """
        pass

    def test_repo_apply_diff_patch(self):
        """Test case for repo_apply_diff_patch

        Apply diff patch to repository  # noqa: E501
        """
        pass

    def test_repo_cancel_scheduled_auto_merge(self):
        """Test case for repo_cancel_scheduled_auto_merge

        Cancel the scheduled auto merge for the given pull request  # noqa: E501
        """
        pass

    def test_repo_check_collaborator(self):
        """Test case for repo_check_collaborator

        Check if a user is a collaborator of a repository  # noqa: E501
        """
        pass

    def test_repo_check_team(self):
        """Test case for repo_check_team

        Check if a team is assigned to a repository  # noqa: E501
        """
        pass

    def test_repo_create_branch(self):
        """Test case for repo_create_branch

        Create a branch  # noqa: E501
        """
        pass

    def test_repo_create_branch_protection(self):
        """Test case for repo_create_branch_protection

        Create a branch protections for a repository  # noqa: E501
        """
        pass

    def test_repo_create_file(self):
        """Test case for repo_create_file

        Create a file in a repository  # noqa: E501
        """
        pass

    def test_repo_create_hook(self):
        """Test case for repo_create_hook

        Create a hook  # noqa: E501
        """
        pass

    def test_repo_create_key(self):
        """Test case for repo_create_key

        Add a key to a repository  # noqa: E501
        """
        pass

    def test_repo_create_pull_request(self):
        """Test case for repo_create_pull_request

        Create a pull request  # noqa: E501
        """
        pass

    def test_repo_create_pull_review(self):
        """Test case for repo_create_pull_review

        Create a review to an pull request  # noqa: E501
        """
        pass

    def test_repo_create_pull_review_requests(self):
        """Test case for repo_create_pull_review_requests

        create review requests for a pull request  # noqa: E501
        """
        pass

    def test_repo_create_release(self):
        """Test case for repo_create_release

        Create a release  # noqa: E501
        """
        pass

    def test_repo_create_release_attachment(self):
        """Test case for repo_create_release_attachment

        Create a release attachment  # noqa: E501
        """
        pass

    def test_repo_create_status(self):
        """Test case for repo_create_status

        Create a commit status  # noqa: E501
        """
        pass

    def test_repo_create_tag(self):
        """Test case for repo_create_tag

        Create a new git tag in a repository  # noqa: E501
        """
        pass

    def test_repo_create_wiki_page(self):
        """Test case for repo_create_wiki_page

        Create a wiki page  # noqa: E501
        """
        pass

    def test_repo_delete(self):
        """Test case for repo_delete

        Delete a repository  # noqa: E501
        """
        pass

    def test_repo_delete_branch(self):
        """Test case for repo_delete_branch

        Delete a specific branch from a repository  # noqa: E501
        """
        pass

    def test_repo_delete_branch_protection(self):
        """Test case for repo_delete_branch_protection

        Delete a specific branch protection for the repository  # noqa: E501
        """
        pass

    def test_repo_delete_collaborator(self):
        """Test case for repo_delete_collaborator

        Delete a collaborator from a repository  # noqa: E501
        """
        pass

    def test_repo_delete_file(self):
        """Test case for repo_delete_file

        Delete a file in a repository  # noqa: E501
        """
        pass

    def test_repo_delete_git_hook(self):
        """Test case for repo_delete_git_hook

        Delete a Git hook in a repository  # noqa: E501
        """
        pass

    def test_repo_delete_hook(self):
        """Test case for repo_delete_hook

        Delete a hook in a repository  # noqa: E501
        """
        pass

    def test_repo_delete_key(self):
        """Test case for repo_delete_key

        Delete a key from a repository  # noqa: E501
        """
        pass

    def test_repo_delete_pull_review(self):
        """Test case for repo_delete_pull_review

        Delete a specific review from a pull request  # noqa: E501
        """
        pass

    def test_repo_delete_pull_review_requests(self):
        """Test case for repo_delete_pull_review_requests

        cancel review requests for a pull request  # noqa: E501
        """
        pass

    def test_repo_delete_push_mirror(self):
        """Test case for repo_delete_push_mirror

        deletes a push mirror from a repository by remoteName  # noqa: E501
        """
        pass

    def test_repo_delete_release(self):
        """Test case for repo_delete_release

        Delete a release  # noqa: E501
        """
        pass

    def test_repo_delete_release_attachment(self):
        """Test case for repo_delete_release_attachment

        Delete a release attachment  # noqa: E501
        """
        pass

    def test_repo_delete_release_by_tag(self):
        """Test case for repo_delete_release_by_tag

        Delete a release by tag name  # noqa: E501
        """
        pass

    def test_repo_delete_tag(self):
        """Test case for repo_delete_tag

        Delete a repository's tag by name  # noqa: E501
        """
        pass

    def test_repo_delete_team(self):
        """Test case for repo_delete_team

        Delete a team from a repository  # noqa: E501
        """
        pass

    def test_repo_delete_topic(self):
        """Test case for repo_delete_topic

        Delete a topic from a repository  # noqa: E501
        """
        pass

    def test_repo_delete_wiki_page(self):
        """Test case for repo_delete_wiki_page

        Delete a wiki page  # noqa: E501
        """
        pass

    def test_repo_dismiss_pull_review(self):
        """Test case for repo_dismiss_pull_review

        Dismiss a review for a pull request  # noqa: E501
        """
        pass

    def test_repo_download_commit_diff_or_patch(self):
        """Test case for repo_download_commit_diff_or_patch

        Get a commit's diff or patch  # noqa: E501
        """
        pass

    def test_repo_download_pull_diff_or_patch(self):
        """Test case for repo_download_pull_diff_or_patch

        Get a pull request diff or patch  # noqa: E501
        """
        pass

    def test_repo_edit(self):
        """Test case for repo_edit

        Edit a repository's properties. Only fields that are set will be changed.  # noqa: E501
        """
        pass

    def test_repo_edit_branch_protection(self):
        """Test case for repo_edit_branch_protection

        Edit a branch protections for a repository. Only fields that are set will be changed  # noqa: E501
        """
        pass

    def test_repo_edit_git_hook(self):
        """Test case for repo_edit_git_hook

        Edit a Git hook in a repository  # noqa: E501
        """
        pass

    def test_repo_edit_hook(self):
        """Test case for repo_edit_hook

        Edit a hook in a repository  # noqa: E501
        """
        pass

    def test_repo_edit_pull_request(self):
        """Test case for repo_edit_pull_request

        Update a pull request. If using deadline only the date will be taken into account, and time of day ignored.  # noqa: E501
        """
        pass

    def test_repo_edit_release(self):
        """Test case for repo_edit_release

        Update a release  # noqa: E501
        """
        pass

    def test_repo_edit_release_attachment(self):
        """Test case for repo_edit_release_attachment

        Edit a release attachment  # noqa: E501
        """
        pass

    def test_repo_edit_wiki_page(self):
        """Test case for repo_edit_wiki_page

        Edit a wiki page  # noqa: E501
        """
        pass

    def test_repo_get(self):
        """Test case for repo_get

        Get a repository  # noqa: E501
        """
        pass

    def test_repo_get_all_commits(self):
        """Test case for repo_get_all_commits

        Get a list of all commits from a repository  # noqa: E501
        """
        pass

    def test_repo_get_archive(self):
        """Test case for repo_get_archive

        Get an archive of a repository  # noqa: E501
        """
        pass

    def test_repo_get_assignees(self):
        """Test case for repo_get_assignees

        Return all users that have write access and can be assigned to issues  # noqa: E501
        """
        pass

    def test_repo_get_branch(self):
        """Test case for repo_get_branch

        Retrieve a specific branch from a repository, including its effective branch protection  # noqa: E501
        """
        pass

    def test_repo_get_branch_protection(self):
        """Test case for repo_get_branch_protection

        Get a specific branch protection for the repository  # noqa: E501
        """
        pass

    def test_repo_get_by_id(self):
        """Test case for repo_get_by_id

        Get a repository by id  # noqa: E501
        """
        pass

    def test_repo_get_combined_status_by_ref(self):
        """Test case for repo_get_combined_status_by_ref

        Get a commit's combined status, by branch/tag/commit reference  # noqa: E501
        """
        pass

    def test_repo_get_contents(self):
        """Test case for repo_get_contents

        Gets the metadata and contents (if a file) of an entry in a repository, or a list of entries if a dir  # noqa: E501
        """
        pass

    def test_repo_get_contents_list(self):
        """Test case for repo_get_contents_list

        Gets the metadata of all the entries of the root dir  # noqa: E501
        """
        pass

    def test_repo_get_editor_config(self):
        """Test case for repo_get_editor_config

        Get the EditorConfig definitions of a file in a repository  # noqa: E501
        """
        pass

    def test_repo_get_git_hook(self):
        """Test case for repo_get_git_hook

        Get a Git hook  # noqa: E501
        """
        pass

    def test_repo_get_hook(self):
        """Test case for repo_get_hook

        Get a hook  # noqa: E501
        """
        pass

    def test_repo_get_issue_templates(self):
        """Test case for repo_get_issue_templates

        Get available issue templates for a repository  # noqa: E501
        """
        pass

    def test_repo_get_key(self):
        """Test case for repo_get_key

        Get a repository's key by id  # noqa: E501
        """
        pass

    def test_repo_get_languages(self):
        """Test case for repo_get_languages

        Get languages and number of bytes of code written  # noqa: E501
        """
        pass

    def test_repo_get_latest_release(self):
        """Test case for repo_get_latest_release

        Gets the most recent non-prerelease, non-draft release of a repository, sorted by created_at  # noqa: E501
        """
        pass

    def test_repo_get_note(self):
        """Test case for repo_get_note

        Get a note corresponding to a single commit from a repository  # noqa: E501
        """
        pass

    def test_repo_get_pull_request(self):
        """Test case for repo_get_pull_request

        Get a pull request  # noqa: E501
        """
        pass

    def test_repo_get_pull_request_commits(self):
        """Test case for repo_get_pull_request_commits

        Get commits for a pull request  # noqa: E501
        """
        pass

    def test_repo_get_pull_request_files(self):
        """Test case for repo_get_pull_request_files

        Get changed files for a pull request  # noqa: E501
        """
        pass

    def test_repo_get_pull_review(self):
        """Test case for repo_get_pull_review

        Get a specific review for a pull request  # noqa: E501
        """
        pass

    def test_repo_get_pull_review_comments(self):
        """Test case for repo_get_pull_review_comments

        Get a specific review for a pull request  # noqa: E501
        """
        pass

    def test_repo_get_push_mirror_by_remote_name(self):
        """Test case for repo_get_push_mirror_by_remote_name

        Get push mirror of the repository by remoteName  # noqa: E501
        """
        pass

    def test_repo_get_raw_file(self):
        """Test case for repo_get_raw_file

        Get a file from a repository  # noqa: E501
        """
        pass

    def test_repo_get_raw_file_or_lfs(self):
        """Test case for repo_get_raw_file_or_lfs

        Get a file or it's LFS object from a repository  # noqa: E501
        """
        pass

    def test_repo_get_release(self):
        """Test case for repo_get_release

        Get a release  # noqa: E501
        """
        pass

    def test_repo_get_release_attachment(self):
        """Test case for repo_get_release_attachment

        Get a release attachment  # noqa: E501
        """
        pass

    def test_repo_get_release_by_tag(self):
        """Test case for repo_get_release_by_tag

        Get a release by tag name  # noqa: E501
        """
        pass

    def test_repo_get_repo_permissions(self):
        """Test case for repo_get_repo_permissions

        Get repository permissions for a user  # noqa: E501
        """
        pass

    def test_repo_get_reviewers(self):
        """Test case for repo_get_reviewers

        Return all users that can be requested to review in this repo  # noqa: E501
        """
        pass

    def test_repo_get_single_commit(self):
        """Test case for repo_get_single_commit

        Get a single commit from a repository  # noqa: E501
        """
        pass

    def test_repo_get_tag(self):
        """Test case for repo_get_tag

        Get the tag of a repository by tag name  # noqa: E501
        """
        pass

    def test_repo_get_wiki_page(self):
        """Test case for repo_get_wiki_page

        Get a wiki page  # noqa: E501
        """
        pass

    def test_repo_get_wiki_page_revisions(self):
        """Test case for repo_get_wiki_page_revisions

        Get revisions of a wiki page  # noqa: E501
        """
        pass

    def test_repo_get_wiki_pages(self):
        """Test case for repo_get_wiki_pages

        Get all wiki pages  # noqa: E501
        """
        pass

    def test_repo_list_all_git_refs(self):
        """Test case for repo_list_all_git_refs

        Get specified ref or filtered repository's refs  # noqa: E501
        """
        pass

    def test_repo_list_branch_protection(self):
        """Test case for repo_list_branch_protection

        List branch protections for a repository  # noqa: E501
        """
        pass

    def test_repo_list_branches(self):
        """Test case for repo_list_branches

        List a repository's branches  # noqa: E501
        """
        pass

    def test_repo_list_collaborators(self):
        """Test case for repo_list_collaborators

        List a repository's collaborators  # noqa: E501
        """
        pass

    def test_repo_list_git_hooks(self):
        """Test case for repo_list_git_hooks

        List the Git hooks in a repository  # noqa: E501
        """
        pass

    def test_repo_list_git_refs(self):
        """Test case for repo_list_git_refs

        Get specified ref or filtered repository's refs  # noqa: E501
        """
        pass

    def test_repo_list_hooks(self):
        """Test case for repo_list_hooks

        List the hooks in a repository  # noqa: E501
        """
        pass

    def test_repo_list_keys(self):
        """Test case for repo_list_keys

        List a repository's keys  # noqa: E501
        """
        pass

    def test_repo_list_pull_requests(self):
        """Test case for repo_list_pull_requests

        List a repo's pull requests  # noqa: E501
        """
        pass

    def test_repo_list_pull_reviews(self):
        """Test case for repo_list_pull_reviews

        List all reviews for a pull request  # noqa: E501
        """
        pass

    def test_repo_list_push_mirrors(self):
        """Test case for repo_list_push_mirrors

        Get all push mirrors of the repository  # noqa: E501
        """
        pass

    def test_repo_list_release_attachments(self):
        """Test case for repo_list_release_attachments

        List release's attachments  # noqa: E501
        """
        pass

    def test_repo_list_releases(self):
        """Test case for repo_list_releases

        List a repo's releases  # noqa: E501
        """
        pass

    def test_repo_list_stargazers(self):
        """Test case for repo_list_stargazers

        List a repo's stargazers  # noqa: E501
        """
        pass

    def test_repo_list_statuses(self):
        """Test case for repo_list_statuses

        Get a commit's statuses  # noqa: E501
        """
        pass

    def test_repo_list_statuses_by_ref(self):
        """Test case for repo_list_statuses_by_ref

        Get a commit's statuses, by branch/tag/commit reference  # noqa: E501
        """
        pass

    def test_repo_list_subscribers(self):
        """Test case for repo_list_subscribers

        List a repo's watchers  # noqa: E501
        """
        pass

    def test_repo_list_tags(self):
        """Test case for repo_list_tags

        List a repository's tags  # noqa: E501
        """
        pass

    def test_repo_list_teams(self):
        """Test case for repo_list_teams

        List a repository's teams  # noqa: E501
        """
        pass

    def test_repo_list_topics(self):
        """Test case for repo_list_topics

        Get list of topics that a repository has  # noqa: E501
        """
        pass

    def test_repo_merge_pull_request(self):
        """Test case for repo_merge_pull_request

        Merge a pull request  # noqa: E501
        """
        pass

    def test_repo_migrate(self):
        """Test case for repo_migrate

        Migrate a remote git repository  # noqa: E501
        """
        pass

    def test_repo_mirror_sync(self):
        """Test case for repo_mirror_sync

        Sync a mirrored repository  # noqa: E501
        """
        pass

    def test_repo_pull_request_is_merged(self):
        """Test case for repo_pull_request_is_merged

        Check if a pull request has been merged  # noqa: E501
        """
        pass

    def test_repo_push_mirror_sync(self):
        """Test case for repo_push_mirror_sync

        Sync all push mirrored repository  # noqa: E501
        """
        pass

    def test_repo_search(self):
        """Test case for repo_search

        Search for repositories  # noqa: E501
        """
        pass

    def test_repo_signing_key(self):
        """Test case for repo_signing_key

        Get signing-key.gpg for given repository  # noqa: E501
        """
        pass

    def test_repo_submit_pull_review(self):
        """Test case for repo_submit_pull_review

        Submit a pending review to an pull request  # noqa: E501
        """
        pass

    def test_repo_test_hook(self):
        """Test case for repo_test_hook

        Test a push webhook  # noqa: E501
        """
        pass

    def test_repo_tracked_times(self):
        """Test case for repo_tracked_times

        List a repo's tracked times  # noqa: E501
        """
        pass

    def test_repo_transfer(self):
        """Test case for repo_transfer

        Transfer a repo ownership  # noqa: E501
        """
        pass

    def test_repo_un_dismiss_pull_review(self):
        """Test case for repo_un_dismiss_pull_review

        Cancel to dismiss a review for a pull request  # noqa: E501
        """
        pass

    def test_repo_update_file(self):
        """Test case for repo_update_file

        Update a file in a repository  # noqa: E501
        """
        pass

    def test_repo_update_pull_request(self):
        """Test case for repo_update_pull_request

        Merge PR's baseBranch into headBranch  # noqa: E501
        """
        pass

    def test_repo_update_topics(self):
        """Test case for repo_update_topics

        Replace list of topics for a repository  # noqa: E501
        """
        pass

    def test_topic_search(self):
        """Test case for topic_search

        search topics via keyword  # noqa: E501
        """
        pass

    def test_user_current_check_subscription(self):
        """Test case for user_current_check_subscription

        Check if the current user is watching a repo  # noqa: E501
        """
        pass

    def test_user_current_delete_subscription(self):
        """Test case for user_current_delete_subscription

        Unwatch a repo  # noqa: E501
        """
        pass

    def test_user_current_put_subscription(self):
        """Test case for user_current_put_subscription

        Watch a repo  # noqa: E501
        """
        pass

    def test_user_tracked_times(self):
        """Test case for user_tracked_times

        List a user's tracked times in a repo  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.create_action_workflow_dispatch import CreateActionWorkflowDispatch

class TestCreateActionWorkflowDispatch(unittest.TestCase):
    """CreateActionWorkflowDispatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateActionWorkflowDispatch:
        """Test CreateActionWorkflowDispatch
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateActionWorkflowDispatch`
        """
        model = CreateActionWorkflowDispatch()
        if include_optional:
            return CreateActionWorkflowDispatch(
                inputs = {
                    'key' : ''
                    },
                ref = 'refs/heads/main'
            )
        else:
            return CreateActionWorkflowDispatch(
                ref = 'refs/heads/main',
        )
        """

    def testCreateActionWorkflowDispatch(self):
        """Test CreateActionWorkflowDispatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from py_gitea_opensuse_org.models.package import Package
from py_gitea_opensuse_org.models.package_file import PackageFile

from py_gitea_opensuse_org.api_client import ApiClient, RequestSerialized
from py_gitea_opensuse_org.api_response import ApiResponse
from py_gitea_opensuse_org.rest import RESTResponseType


class PackageApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def delete_package(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_package_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def delete_package_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_package_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def delete_package_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_package_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_package_serialize(
        self,
        owner,
        type,
        name,
        version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        if type is not None:
            _path_params['type'] = type
        if name is not None:
            _path_params['name'] = name
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/packages/{owner}/{type}/{name}/{version}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get_latest_package_version(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Package:
        """Gets the latest version of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_package_version_serialize(
            owner=owner,
            type=type,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Package",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get_latest_package_version_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Package]:
        """Gets the latest version of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_package_version_serialize(
            owner=owner,
            type=type,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Package",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get_latest_package_version_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets the latest version of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_package_version_serialize(
            owner=owner,
            type=type,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Package",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_latest_package_version_serialize(
        self,
        owner,
        type,
        name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        if type is not None:
            _path_params['type'] = type
        if name is not None:
            _path_params['name'] = name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/packages/{owner}/{type}/{name}/-/latest',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get_package(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Package:
        """Gets a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_package_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Package",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get_package_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Package]:
        """Gets a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_package_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Package",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get_package_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_package_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Package",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_package_serialize(
        self,
        owner,
        type,
        name,
        version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        if type is not None:
            _path_params['type'] = type
        if name is not None:
            _path_params['name'] = name
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/packages/{owner}/{type}/{name}/{version}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def link_package(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        repo_name: Annotated[StrictStr, Field(description="name of the repository to link.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Link a package to a repository


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param repo_name: name of the repository to link. (required)
        :type repo_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._link_package_serialize(
            owner=owner,
            type=type,
            name=name,
            repo_name=repo_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def link_package_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        repo_name: Annotated[StrictStr, Field(description="name of the repository to link.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Link a package to a repository


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param repo_name: name of the repository to link. (required)
        :type repo_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._link_package_serialize(
            owner=owner,
            type=type,
            name=name,
            repo_name=repo_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def link_package_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        repo_name: Annotated[StrictStr, Field(description="name of the repository to link.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Link a package to a repository


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param repo_name: name of the repository to link. (required)
        :type repo_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._link_package_serialize(
            owner=owner,
            type=type,
            name=name,
            repo_name=repo_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _link_package_serialize(
        self,
        owner,
        type,
        name,
        repo_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        if type is not None:
            _path_params['type'] = type
        if name is not None:
            _path_params['name'] = name
        if repo_name is not None:
            _path_params['repo_name'] = repo_name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/packages/{owner}/{type}/{name}/-/link/{repo_name}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list_package_files(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PackageFile]:
        """Gets all files of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_package_files_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PackageFile]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_package_files_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PackageFile]]:
        """Gets all files of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_package_files_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PackageFile]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_package_files_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        version: Annotated[StrictStr, Field(description="version of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets all files of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param version: version of the package (required)
        :type version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_package_files_serialize(
            owner=owner,
            type=type,
            name=name,
            version=version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PackageFile]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_package_files_serialize(
        self,
        owner,
        type,
        name,
        version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        if type is not None:
            _path_params['type'] = type
        if name is not None:
            _path_params['name'] = name
        if version is not None:
            _path_params['version'] = version
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/packages/{owner}/{type}/{name}/{version}/files',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list_package_versions(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        page: Annotated[Optional[StrictInt], Field(description="page number of results to return (1-based)")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="page size of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Package]:
        """Gets all versions of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param page: page number of results to return (1-based)
        :type page: int
        :param limit: page size of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_package_versions_serialize(
            owner=owner,
            type=type,
            name=name,
            page=page,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Package]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_package_versions_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        page: Annotated[Optional[StrictInt], Field(description="page number of results to return (1-based)")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="page size of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Package]]:
        """Gets all versions of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param page: page number of results to return (1-based)
        :type page: int
        :param limit: page size of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_package_versions_serialize(
            owner=owner,
            type=type,
            name=name,
            page=page,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Package]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_package_versions_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        page: Annotated[Optional[StrictInt], Field(description="page number of results to return (1-based)")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="page size of results")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets all versions of a package


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param page: page number of results to return (1-based)
        :type page: int
        :param limit: page size of results
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_package_versions_serialize(
            owner=owner,
            type=type,
            name=name,
            page=page,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Package]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_package_versions_serialize(
        self,
        owner,
        type,
        name,
        page,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        if type is not None:
            _path_params['type'] = type
        if name is not None:
            _path_params['name'] = name
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/packages/{owner}/{type}/{name}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list_packages(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the packages")],
        page: Annotated[Optional[StrictInt], Field(description="page number of results to return (1-based)")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="page size of results")] = None,
        type: Annotated[Optional[StrictStr], Field(description="package type filter")] = None,
        q: Annotated[Optional[StrictStr], Field(description="name filter")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Package]:
        """Gets all packages of an owner


        :param owner: owner of the packages (required)
        :type owner: str
        :param page: page number of results to return (1-based)
        :type page: int
        :param limit: page size of results
        :type limit: int
        :param type: package type filter
        :type type: str
        :param q: name filter
        :type q: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_packages_serialize(
            owner=owner,
            page=page,
            limit=limit,
            type=type,
            q=q,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Package]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_packages_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the packages")],
        page: Annotated[Optional[StrictInt], Field(description="page number of results to return (1-based)")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="page size of results")] = None,
        type: Annotated[Optional[StrictStr], Field(description="package type filter")] = None,
        q: Annotated[Optional[StrictStr], Field(description="name filter")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Package]]:
        """Gets all packages of an owner


        :param owner: owner of the packages (required)
        :type owner: str
        :param page: page number of results to return (1-based)
        :type page: int
        :param limit: page size of results
        :type limit: int
        :param type: package type filter
        :type type: str
        :param q: name filter
        :type q: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_packages_serialize(
            owner=owner,
            page=page,
            limit=limit,
            type=type,
            q=q,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Package]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_packages_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the packages")],
        page: Annotated[Optional[StrictInt], Field(description="page number of results to return (1-based)")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="page size of results")] = None,
        type: Annotated[Optional[StrictStr], Field(description="package type filter")] = None,
        q: Annotated[Optional[StrictStr], Field(description="name filter")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets all packages of an owner


        :param owner: owner of the packages (required)
        :type owner: str
        :param page: page number of results to return (1-based)
        :type page: int
        :param limit: page size of results
        :type limit: int
        :param type: package type filter
        :type type: str
        :param q: name filter
        :type q: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_packages_serialize(
            owner=owner,
            page=page,
            limit=limit,
            type=type,
            q=q,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Package]",
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_packages_serialize(
        self,
        owner,
        page,
        limit,
        type,
        q,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if type is not None:
            
            _query_params.append(('type', type))
            
        if q is not None:
            
            _query_params.append(('q', q))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/packages/{owner}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def unlink_package(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Unlink a package from a repository


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._unlink_package_serialize(
            owner=owner,
            type=type,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def unlink_package_with_http_info(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Unlink a package from a repository


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._unlink_package_serialize(
            owner=owner,
            type=type,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def unlink_package_without_preload_content(
        self,
        owner: Annotated[StrictStr, Field(description="owner of the package")],
        type: Annotated[StrictStr, Field(description="type of the package")],
        name: Annotated[StrictStr, Field(description="name of the package")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Unlink a package from a repository


        :param owner: owner of the package (required)
        :type owner: str
        :param type: type of the package (required)
        :type type: str
        :param name: name of the package (required)
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._unlink_package_serialize(
            owner=owner,
            type=type,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '404': None,
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _unlink_package_serialize(
        self,
        owner,
        type,
        name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner is not None:
            _path_params['owner'] = owner
        if type is not None:
            _path_params['type'] = type
        if name is not None:
            _path_params['name'] = name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'TOTPHeader', 
            'AuthorizationHeaderToken', 
            'SudoHeader', 
            'BasicAuth', 
            'AccessToken', 
            'SudoParam', 
            'Token'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/packages/{owner}/{type}/{name}/-/unlink',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.attachment import Attachment
from py_gitea_opensuse_org.models.label import Label
from py_gitea_opensuse_org.models.milestone import Milestone
from py_gitea_opensuse_org.models.pull_request_meta import PullRequestMeta
from py_gitea_opensuse_org.models.repository_meta import RepositoryMeta
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Issue(BaseModel):
    """
    Issue represents an issue in a repository
    """ # noqa: E501
    assets: Optional[List[Attachment]] = None
    assignee: Optional[User] = None
    assignees: Optional[List[User]] = None
    body: Optional[StrictStr] = None
    closed_at: Optional[datetime] = None
    comments: Optional[StrictInt] = None
    created_at: Optional[datetime] = None
    due_date: Optional[datetime] = None
    html_url: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    is_locked: Optional[StrictBool] = None
    labels: Optional[List[Label]] = None
    milestone: Optional[Milestone] = None
    number: Optional[StrictInt] = None
    original_author: Optional[StrictStr] = None
    original_author_id: Optional[StrictInt] = None
    pin_order: Optional[StrictInt] = None
    pull_request: Optional[PullRequestMeta] = None
    ref: Optional[StrictStr] = None
    repository: Optional[RepositoryMeta] = None
    state: Optional[StrictStr] = Field(default=None, description="StateType issue state type")
    title: Optional[StrictStr] = None
    updated_at: Optional[datetime] = None
    url: Optional[StrictStr] = None
    user: Optional[User] = None
    __properties: ClassVar[List[str]] = ["assets", "assignee", "assignees", "body", "closed_at", "comments", "created_at", "due_date", "html_url", "id", "is_locked", "labels", "milestone", "number", "original_author", "original_author_id", "pin_order", "pull_request", "ref", "repository", "state", "title", "updated_at", "url", "user"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Issue from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in assets (list)
        _items = []
        if self.assets:
            for _item_assets in self.assets:
                if _item_assets:
                    _items.append(_item_assets.to_dict())
            _dict['assets'] = _items
        # override the default output from pydantic by calling `to_dict()` of assignee
        if self.assignee:
            _dict['assignee'] = self.assignee.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in assignees (list)
        _items = []
        if self.assignees:
            for _item_assignees in self.assignees:
                if _item_assignees:
                    _items.append(_item_assignees.to_dict())
            _dict['assignees'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict['labels'] = _items
        # override the default output from pydantic by calling `to_dict()` of milestone
        if self.milestone:
            _dict['milestone'] = self.milestone.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pull_request
        if self.pull_request:
            _dict['pull_request'] = self.pull_request.to_dict()
        # override the default output from pydantic by calling `to_dict()` of repository
        if self.repository:
            _dict['repository'] = self.repository.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Issue from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "assets": [Attachment.from_dict(_item) for _item in obj["assets"]] if obj.get("assets") is not None else None,
            "assignee": User.from_dict(obj["assignee"]) if obj.get("assignee") is not None else None,
            "assignees": [User.from_dict(_item) for _item in obj["assignees"]] if obj.get("assignees") is not None else None,
            "body": obj.get("body"),
            "closed_at": obj.get("closed_at"),
            "comments": obj.get("comments"),
            "created_at": obj.get("created_at"),
            "due_date": obj.get("due_date"),
            "html_url": obj.get("html_url"),
            "id": obj.get("id"),
            "is_locked": obj.get("is_locked"),
            "labels": [Label.from_dict(_item) for _item in obj["labels"]] if obj.get("labels") is not None else None,
            "milestone": Milestone.from_dict(obj["milestone"]) if obj.get("milestone") is not None else None,
            "number": obj.get("number"),
            "original_author": obj.get("original_author"),
            "original_author_id": obj.get("original_author_id"),
            "pin_order": obj.get("pin_order"),
            "pull_request": PullRequestMeta.from_dict(obj["pull_request"]) if obj.get("pull_request") is not None else None,
            "ref": obj.get("ref"),
            "repository": RepositoryMeta.from_dict(obj["repository"]) if obj.get("repository") is not None else None,
            "state": obj.get("state"),
            "title": obj.get("title"),
            "updated_at": obj.get("updated_at"),
            "url": obj.get("url"),
            "user": User.from_dict(obj["user"]) if obj.get("user") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.gpg_key_email import GPGKeyEmail
from typing import Optional, Set
from typing_extensions import Self

class GPGKey(BaseModel):
    """
    GPGKey a user GPG key to sign commit and tag in repository
    """ # noqa: E501
    can_certify: Optional[StrictBool] = None
    can_encrypt_comms: Optional[StrictBool] = None
    can_encrypt_storage: Optional[StrictBool] = None
    can_sign: Optional[StrictBool] = None
    created_at: Optional[datetime] = None
    emails: Optional[List[GPGKeyEmail]] = None
    expires_at: Optional[datetime] = None
    id: Optional[StrictInt] = None
    key_id: Optional[StrictStr] = None
    primary_key_id: Optional[StrictStr] = None
    public_key: Optional[StrictStr] = None
    subkeys: Optional[List[GPGKey]] = None
    verified: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["can_certify", "can_encrypt_comms", "can_encrypt_storage", "can_sign", "created_at", "emails", "expires_at", "id", "key_id", "primary_key_id", "public_key", "subkeys", "verified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GPGKey from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in emails (list)
        _items = []
        if self.emails:
            for _item_emails in self.emails:
                if _item_emails:
                    _items.append(_item_emails.to_dict())
            _dict['emails'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in subkeys (list)
        _items = []
        if self.subkeys:
            for _item_subkeys in self.subkeys:
                if _item_subkeys:
                    _items.append(_item_subkeys.to_dict())
            _dict['subkeys'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GPGKey from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "can_certify": obj.get("can_certify"),
            "can_encrypt_comms": obj.get("can_encrypt_comms"),
            "can_encrypt_storage": obj.get("can_encrypt_storage"),
            "can_sign": obj.get("can_sign"),
            "created_at": obj.get("created_at"),
            "emails": [GPGKeyEmail.from_dict(_item) for _item in obj["emails"]] if obj.get("emails") is not None else None,
            "expires_at": obj.get("expires_at"),
            "id": obj.get("id"),
            "key_id": obj.get("key_id"),
            "primary_key_id": obj.get("primary_key_id"),
            "public_key": obj.get("public_key"),
            "subkeys": [GPGKey.from_dict(_item) for _item in obj["subkeys"]] if obj.get("subkeys") is not None else None,
            "verified": obj.get("verified")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
GPGKey.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.commit_affected_files import CommitAffectedFiles
from py_gitea_opensuse_org.models.commit_meta import CommitMeta
from py_gitea_opensuse_org.models.commit_stats import CommitStats
from py_gitea_opensuse_org.models.repo_commit import RepoCommit
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Commit(BaseModel):
    """
    Commit
    """ # noqa: E501
    author: Optional[User] = None
    commit: Optional[RepoCommit] = None
    committer: Optional[User] = None
    created: Optional[datetime] = None
    files: Optional[List[CommitAffectedFiles]] = None
    html_url: Optional[StrictStr] = None
    parents: Optional[List[CommitMeta]] = None
    sha: Optional[StrictStr] = None
    stats: Optional[CommitStats] = None
    url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["author", "commit", "committer", "created", "files", "html_url", "parents", "sha", "stats", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Commit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of author
        if self.author:
            _dict['author'] = self.author.to_dict()
        # override the default output from pydantic by calling `to_dict()` of commit
        if self.commit:
            _dict['commit'] = self.commit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of committer
        if self.committer:
            _dict['committer'] = self.committer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in files (list)
        _items = []
        if self.files:
            for _item_files in self.files:
                if _item_files:
                    _items.append(_item_files.to_dict())
            _dict['files'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in parents (list)
        _items = []
        if self.parents:
            for _item_parents in self.parents:
                if _item_parents:
                    _items.append(_item_parents.to_dict())
            _dict['parents'] = _items
        # override the default output from pydantic by calling `to_dict()` of stats
        if self.stats:
            _dict['stats'] = self.stats.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Commit from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "author": User.from_dict(obj["author"]) if obj.get("author") is not None else None,
            "commit": RepoCommit.from_dict(obj["commit"]) if obj.get("commit") is not None else None,
            "committer": User.from_dict(obj["committer"]) if obj.get("committer") is not None else None,
            "created": obj.get("created"),
            "files": [CommitAffectedFiles.from_dict(_item) for _item in obj["files"]] if obj.get("files") is not None else None,
            "html_url": obj.get("html_url"),
            "parents": [CommitMeta.from_dict(_item) for _item in obj["parents"]] if obj.get("parents") is not None else None,
            "sha": obj.get("sha"),
            "stats": CommitStats.from_dict(obj["stats"]) if obj.get("stats") is not None else None,
            "url": obj.get("url")
        })
        return _obj





# flake8: noqa

if __import__("typing").TYPE_CHECKING:
    # import apis into api package
    from py_gitea_opensuse_org.api.activitypub_api import ActivitypubApi
    from py_gitea_opensuse_org.api.admin_api import AdminApi
    from py_gitea_opensuse_org.api.issue_api import IssueApi
    from py_gitea_opensuse_org.api.miscellaneous_api import MiscellaneousApi
    from py_gitea_opensuse_org.api.notification_api import NotificationApi
    from py_gitea_opensuse_org.api.organization_api import OrganizationApi
    from py_gitea_opensuse_org.api.package_api import PackageApi
    from py_gitea_opensuse_org.api.repository_api import RepositoryApi
    from py_gitea_opensuse_org.api.settings_api import SettingsApi
    from py_gitea_opensuse_org.api.user_api import UserApi
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import apis into api package
from py_gitea_opensuse_org.api.activitypub_api import ActivitypubApi
from py_gitea_opensuse_org.api.admin_api import AdminApi
from py_gitea_opensuse_org.api.issue_api import IssueApi
from py_gitea_opensuse_org.api.miscellaneous_api import MiscellaneousApi
from py_gitea_opensuse_org.api.notification_api import NotificationApi
from py_gitea_opensuse_org.api.organization_api import OrganizationApi
from py_gitea_opensuse_org.api.package_api import PackageApi
from py_gitea_opensuse_org.api.repository_api import RepositoryApi
from py_gitea_opensuse_org.api.settings_api import SettingsApi
from py_gitea_opensuse_org.api.user_api import UserApi

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreateUserOption(BaseModel):
    """
    CreateUserOption create user options
    """ # noqa: E501
    created_at: Optional[datetime] = Field(default=None, description="For explicitly setting the user creation timestamp. Useful when users are migrated from other systems. When omitted, the user's creation timestamp will be set to \"now\".")
    email: StrictStr
    full_name: Optional[StrictStr] = None
    login_name: Optional[StrictStr] = None
    must_change_password: Optional[StrictBool] = None
    password: Optional[StrictStr] = None
    restricted: Optional[StrictBool] = None
    send_notify: Optional[StrictBool] = None
    source_id: Optional[StrictInt] = None
    username: StrictStr
    visibility: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["created_at", "email", "full_name", "login_name", "must_change_password", "password", "restricted", "send_notify", "source_id", "username", "visibility"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateUserOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateUserOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "email": obj.get("email"),
            "full_name": obj.get("full_name"),
            "login_name": obj.get("login_name"),
            "must_change_password": obj.get("must_change_password"),
            "password": obj.get("password"),
            "restricted": obj.get("restricted"),
            "send_notify": obj.get("send_notify"),
            "source_id": obj.get("source_id"),
            "username": obj.get("username"),
            "visibility": obj.get("visibility")
        })
        return _obj


